Calculates the difference between two lists using Paul Heckel’s algorithm from 1978. (https://dl.acm.org/doi/10.1145/359460.359467)
Enums
Functions
- diff
- The difference between the two slices is calculated. The changes are in the order that constructs the new version from the old version.
- new_
version - Produces the new version of the list from the calculated changes.
- old_
version - Produces the old version of the list from the calculated changes.